import { isVNode, defineComponent, inject, ref, computed, watch, nextTick, unref, createVNode, mergeProps } from 'vue';
import { get } from 'lodash-unified';
import '../../../utils/index.mjs';
import '../../virtual-list/index.mjs';
import { ElCheckbox } from '../../checkbox/index.mjs';
import '../../../hooks/index.mjs';
import { ElButton } from '../../button/index.mjs';
import '../../../constants/index.mjs';
import GroupItem from './group-item.mjs';
import OptionItem from './option-item.mjs';
import OptionItemCheckbox from './option-item-checkbox.mjs';
import { selectV2InjectionKey } from './token.mjs';
import { useNamespace } from '../../../hooks/use-namespace/index.mjs';
import { useLocale } from '../../../hooks/use-locale/index.mjs';
import { isUndefined } from '../../../utils/types.mjs';
import { isObject } from '@vue/shared';
import { EVENT_CODE } from '../../../constants/aria.mjs';
import FixedSizeList from '../../virtual-list/src/components/fixed-size-list.mjs';
import DynamicSizeList from '../../virtual-list/src/components/dynamic-size-list.mjs';

function _isSlot(s) {
  return typeof s === "function" || Object.prototype.toString.call(s) === "[object Object]" && !isVNode(s);
}
var ElSelectMenu = defineComponent({
  name: "ElSelectDropdown",
  props: {
    data: {
      type: Array,
      required: true
    },
    hoveringIndex: Number,
    width: Number
  },
  setup(props, {
    slots,
    expose
  }) {
    const select = inject(selectV2InjectionKey);
    const ns = useNamespace("select");
    const {
      t
    } = useLocale();
    const cachedHeights = ref([]);
    const listRef = ref();
    const {
      props: {
        modelValue,
        showChecked,
        valueKey
      }
    } = select;
    const checkAll = ref(false);
    const isIndeterminate = ref(false);
    const handleCheckAllChange = (val) => {
      checkAll.value = val;
      props.data.forEach((element) => {
        element.checked = val;
      });
      isIndeterminate.value = false;
      onSelectCheckbox(0);
    };
    const size = computed(() => props.data.length);
    watch(() => size.value, () => {
      var _a, _b;
      if (showChecked) {
        setCheckStatus();
      }
      (_b = (_a = select.popper.value).updatePopper) == null ? void 0 : _b.call(_a);
    });
    if (showChecked) {
      props.data.forEach((element) => {
        element.checked = modelValue.includes(get(element, valueKey));
      });
      const checkedCount = modelValue.length;
      checkAll.value = checkedCount === size.value;
      isIndeterminate.value = checkedCount > 0 && checkedCount < size.value;
    }
    const onSelectCheckbox = (index) => {
      select.onHover(index - 1);
      nextTick(() => {
        select.onHover(index);
        setCheckStatus();
      });
    };
    const setCheckStatus = () => {
      const checkedCount = props.data.filter((ele) => ele.checked).length;
      checkAll.value = checkedCount === size.value;
      isIndeterminate.value = checkedCount > 0 && checkedCount < size.value;
    };
    const confirm = () => {
      select.onSelectMultiple((select.props.options || []).filter((ele) => ele.checked));
      select.handleClickOutside();
    };
    const clear = () => {
      handleCheckAllChange(false);
    };
    const isSized = computed(() => isUndefined(select.props.estimatedOptionHeight));
    const listProps = computed(() => {
      if (isSized.value) {
        return {
          itemSize: select.props.itemHeight
        };
      }
      return {
        estimatedSize: select.props.estimatedOptionHeight,
        itemSize: (idx) => cachedHeights.value[idx]
      };
    });
    const contains = (arr = [], target) => {
      const {
        props: {
          valueKey: valueKey2
        }
      } = select;
      if (!isObject(target)) {
        return arr.includes(target);
      }
      return arr && arr.some((item) => {
        return get(item, valueKey2) === get(target, valueKey2);
      });
    };
    const isEqual = (selected, target) => {
      if (!isObject(target)) {
        return selected === target;
      } else {
        const {
          valueKey: valueKey2
        } = select.props;
        return get(selected, valueKey2) === get(target, valueKey2);
      }
    };
    const isItemSelected = (modelValue2, target) => {
      const {
        valueKey: valueKey2
      } = select.props;
      if (select.props.multiple) {
        return contains(modelValue2, get(target, valueKey2));
      }
      return isEqual(modelValue2, get(target, valueKey2));
    };
    const isItemDisabled = (modelValue2, selected) => {
      const {
        disabled,
        multiple,
        multipleLimit
      } = select.props;
      return disabled || !selected && (multiple ? multipleLimit > 0 && modelValue2.length >= multipleLimit : false);
    };
    const isItemHovering = (target) => props.hoveringIndex === target;
    const scrollToItem = (index) => {
      const list = listRef.value;
      if (list) {
        list.scrollToItem(index);
      }
    };
    const resetScrollTop = () => {
      const list = listRef.value;
      if (list) {
        list.resetScrollTop();
      }
    };
    expose({
      listRef,
      isSized,
      isItemDisabled,
      isItemHovering,
      isItemSelected,
      scrollToItem,
      resetScrollTop
    });
    const Item = (itemProps) => {
      const {
        index,
        data,
        style
      } = itemProps;
      const sized = unref(isSized);
      const {
        itemSize,
        estimatedSize
      } = unref(listProps);
      const {
        modelValue: modelValue2,
        showChecked: showChecked2
      } = select.props;
      const {
        onSelect,
        onHover
      } = select;
      const item = data[index];
      if (item.type === "Group") {
        return createVNode(GroupItem, {
          "item": item,
          "style": style,
          "height": sized ? itemSize : estimatedSize
        }, null);
      }
      const isSelected = isItemSelected(modelValue2, item);
      const isDisabled = isItemDisabled(modelValue2, isSelected);
      const isHovering = isItemHovering(index);
      if (showChecked2) {
        return createVNode(OptionItemCheckbox, mergeProps(itemProps, {
          "disabled": item.disabled || isDisabled,
          "created": !!item.created,
          "hovering": isHovering,
          "item": item,
          "onSelect": onSelectCheckbox,
          "onHover": onHover
        }), {
          default: (props2) => {
            var _a;
            return ((_a = slots.default) == null ? void 0 : _a.call(slots, props2)) || createVNode("span", null, [item.label]);
          }
        });
      }
      return createVNode(OptionItem, mergeProps(itemProps, {
        "selected": isSelected,
        "disabled": item.disabled || isDisabled,
        "created": !!item.created,
        "hovering": isHovering,
        "item": item,
        "onSelect": onSelect,
        "onHover": onHover
      }), {
        default: (props2) => {
          var _a;
          return ((_a = slots.default) == null ? void 0 : _a.call(slots, props2)) || createVNode("span", null, [item.label]);
        }
      });
    };
    const {
      onKeyboardNavigate,
      onKeyboardSelect
    } = select;
    const onForward = () => {
      onKeyboardNavigate("forward");
    };
    const onBackward = () => {
      onKeyboardNavigate("backward");
    };
    const onEscOrTab = () => {
      select.expanded = false;
    };
    const onKeydown = (e) => {
      const {
        code
      } = e;
      const {
        tab,
        esc,
        down,
        up,
        enter
      } = EVENT_CODE;
      if (code !== tab) {
        e.preventDefault();
        e.stopPropagation();
      }
      switch (code) {
        case tab:
        case esc: {
          onEscOrTab();
          break;
        }
        case down: {
          onForward();
          break;
        }
        case up: {
          onBackward();
          break;
        }
        case enter: {
          onKeyboardSelect();
          break;
        }
      }
    };
    return () => {
      var _a;
      let _slot, _slot2, _slot3;
      const {
        data,
        width
      } = props;
      const {
        height,
        multiple,
        scrollbarAlwaysOn,
        showChecked: showChecked2
      } = select.props;
      if (data.length === 0) {
        return createVNode("div", {
          "class": ns.b("dropdown"),
          "style": {
            width: `${width}px`
          }
        }, [(_a = slots.empty) == null ? void 0 : _a.call(slots)]);
      }
      const List = unref(isSized) ? FixedSizeList : DynamicSizeList;
      return createVNode("div", {
        "class": [ns.b("dropdown"), ns.is("multiple", multiple)]
      }, [showChecked2 ? createVNode("div", {
        "class": "el-select-dropdown__option-item"
      }, [createVNode(ElCheckbox, {
        "modelValue": checkAll.value,
        "indeterminate": isIndeterminate.value,
        "onChange": handleCheckAllChange
      }, _isSlot(_slot = t("el.colorpicker.selectAll")) ? _slot : {
        default: () => [_slot]
      })]) : null, createVNode(List, mergeProps({
        "ref": listRef
      }, unref(listProps), {
        "className": ns.be("dropdown", "list"),
        "scrollbarAlwaysOn": scrollbarAlwaysOn,
        "data": data,
        "height": height,
        "width": width,
        "total": data.length,
        "onKeydown": onKeydown
      }), {
        default: (props2) => createVNode(Item, props2, null)
      }), showChecked2 ? createVNode("p", {
        "style": {
          textAlign: "center",
          marginTop: 0
        }
      }, [createVNode(ElButton, {
        "onClick": clear,
        "secondary": true
      }, _isSlot(_slot2 = t("el.datepicker.clear")) ? _slot2 : {
        default: () => [_slot2]
      }), createVNode(ElButton, {
        "onClick": confirm,
        "secondary": true
      }, _isSlot(_slot3 = t("el.datepicker.confirm")) ? _slot3 : {
        default: () => [_slot3]
      })]) : null]);
    };
  }
});

export { ElSelectMenu as default };
//# sourceMappingURL=select-dropdown.mjs.map
